==> foundation-ui-components-1.24.1.tgz: package/src/common/accordion/NsAccordionItem.tsx <==
import React from 'react';
import { NsAccordionItemProps, NsCollapse } from '..';
import NsAccordionHeader from './NsAccordionHeader';
import { StyledToggleSection } from './ToggleSection.styled';

/**
 * this component is used by accordion to pass title
 * and content
 * cslp:{header:CslpTag, content:CslpTag}
 */
const NsAccordionItem = ({
    isOpen,
    isChild,
    toggleOpen,
    title,
    content,
    variant,
    headerTypographyVariant,
    closedIconName,
    openedIconName,
    startIcon,
    level,
    additionalProps,
    invert,
    type,
    cslp,
    allowMultipleExpanded,
    showEndIconWhenEmpty,
}: NsAccordionItemProps) => {
    return (
        <StyledToggleSection variant={variant}>
            <NsAccordionHeader
                invert={invert}
                additionalProps={{ ...additionalProps, className: 'accordion-section ' + additionalProps?.className }}
                closedIconName={closedIconName}
                headerTypographyVariant={headerTypographyVariant}
                isOpen={isOpen}
                openedIconName={openedIconName}
                onClick={toggleOpen}
                title={title}
                variant={variant}
                startIcon={startIcon}
                cslp={cslp}
                showEndIconWhenEmpty={showEndIconWhenEmpty}
                content={content}
            />
            {content || showEndIconWhenEmpty ? (
                <NsCollapse
                    type={type}
                    isChild={isChild}
                    isOpen={isOpen}
                    variant={variant}
                    level={level}
                    invert={invert}
                    content={content}
                    cslp={cslp}
                    allowMultipleExpanded={allowMultipleExpanded}
                />
            ) : null}
        </StyledToggleSection>
    );
};

export default NsAccordionItem;

==> foundation-ui-components-1.30.1.tgz: package/src/common/accordion/NsAccordionItem.tsx <==
import React, { ReactElement } from 'react';

import { NsAccordionItemProps, NsCollapse } from '../';
import NsAccordionHeader from './NsAccordionHeader';
import { StyledToggleSection } from './ToggleSection.styled';

/**
 * this component is used by accordion to pass title
 * and content
 * cslp:{header:CslpTag, content:CslpTag}
 */
const NsAccordionItem = ({
    isOpen,
    isChild,
    toggleOpen,
    title,
    content,
    variant,
    headerTypographyVariant,
    closedIconName,
    openedIconName,
    startIcon,
    level,
    additionalProps,
    invert,
    type,
    cslp,
    allowMultipleExpanded,
    showEndIconWhenEmpty,
}: NsAccordionItemProps): ReactElement => {
    return (
        <StyledToggleSection variant={variant}>
            <NsAccordionHeader
                invert={invert}
                additionalProps={{ ...additionalProps, className: 'accordion-section ' + additionalProps?.className }}
                closedIconName={closedIconName}
                headerTypographyVariant={headerTypographyVariant}
                isOpen={isOpen}
                openedIconName={openedIconName}
                onClick={toggleOpen}
                title={title}
                variant={variant}
                startIcon={startIcon}
                cslp={cslp}
                showEndIconWhenEmpty={showEndIconWhenEmpty}
                content={content}
            />
            {content || showEndIconWhenEmpty ? (
                <NsCollapse
                    type={type}
                    isChild={isChild}
                    isOpen={isOpen}
                    variant={variant}
                    level={level}
                    invert={invert}
                    content={content}
                    cslp={cslp}
                    allowMultipleExpanded={allowMultipleExpanded}
                />
            ) : null}
        </StyledToggleSection>
    );
};

export default NsAccordionItem;
